
#ifndef PYRDISP_H

#define PYRDISP_H

/*===============================<o>=====================================

  This software was written by Ian L. Kaplan, Chief Fat Bear, Bear Products
  International.  Use of this software, for any purpose, is granted on two
  conditions: 

   1. This copyright notice must be included with the software
      or any software derived from it.

   2. The risk of using this software is accepted by the user.  No
      warranty as to its usefulness or functionality is provided
      or implied.  The author and Bear Products International provides
      no support.

   July 1996

 ===============================<o>=====================================*/

/*
   The pyramid display class, pyr_display, isolates the openGL operations
   needed to display the Sierpinski pyramid.

 */
   


#include "sier.h"
#include "dxfwrite.h"  // needed for the dxfwrite class


class pyr_display {

// Private class variables
private:  
  typedef enum {Off = 0, On  = 1} bogus;
  GLuint sierpinski_list;
  Sierpinski *pyr;
  // object used to write the Sierpinski pyramid out in DXF format
  dxfwrite dxf_out;



//
// The glRotatef function takes four arguments, the angle of rotation,
// and a 3-D point.  The axis of rotation defined by the line from (0,0,0)
// to the 3-D point.  So to rotate on the X-axis, the point would be
// (1, 0, 0), to rotate on the Y-axis (0, 1, 0) and to rotate on the
// Z-axis (0, 0, 1).
//

  // Rotate first on the X-axis
  int AxisPoint[ 3 ];
  int AxisIx;
  int SpinAngle;       // spin angle, in degrees
  int cur_width, cur_height;

// Private class functions
 private:
  void init_spin_vars(void);
  void gl_init(void);
  //
  // inline functions
  //
  int point_neq(int *a, int *b) { 
    return (a[0] != b[0] || a[1] != b[1] || a[2] != b[2]);
  } // point_neq

public:
  pyr_display(void);
  // called via a pointer in sier2.cpp in the OnIdle function
  void incr_spin_vars(void);
  void set_GL_size(void);
  void build_display_list(void);
  void draw_object(void);
  void new_pyramid( unsigned int power );
  void set_width( int width ) { cur_width = width; }
  void set_height( int height ) { cur_height = height; }
  void pyr_write( FILE *fp ) {
    if (fp == NULL)
      return;
    dxf_out.write_3DFACE( fp, 
	                  pyr->get_facelist(), 
	                  pyr->get_num_faces() );
  }


}; //  pyr_display

#endif
